#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IDXY_BILINEAR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IDXY_BILINEAR_HPP_INCLUDED

#include <nt2/interpol/include/functions/scalar/idxy_bilinear.hpp>

#endif
